@@ -1,4 +1,4 @@
-from pdb import set_trace as T
+# pylint: disable=all
 
 from collections import defaultdict
 import numpy as np
@@ -14,7 +14,7 @@ def rank(policy_ids, scores):
 
     # Double argsort returns ranks
     return np.argsort(np.argsort(
-        [-np.mean(vals) + 1e-8 * np.random.normal() for policy, vals in 
+        [-np.mean(vals) + 1e-8 * np.random.normal() for policy, vals in
         sorted(agents.items())])).tolist()
 
 
